@@ -80,7 +80,7 @@ class TornadoAngularServer(Server):
                 (r'bower_components', join(angular_path, 'bower_components')),
                 (r'scripts', join(angular_path, '.tmp/scripts')),
                 (r'styles', join(angular_path, '.tmp/styles')),
-                (r'images', join(angular_path, 'app/images')),
+                (r'images', join(angular_path, '.tmp/images')),
                 (r'views', join(angular_path, 'app/views')),
             )
         else:
@@ -103,7 +103,7 @@ class TornadoAngularServer(Server):
 
         for url, path in items:
             handlers.append((
-                r"/%s/%s/(.+)" % (web_prefix, url),
+                r"/?%s/%s/(.+)" % (web_prefix, url),
                 tornado.web.StaticFileHandler,
                 {'path': path}
             ))
